@@ -10,7 +10,6 @@ from . import (
     DEFAULT_FREQ,
     freq_from_spec,
     load_budget,
-    plot_budget,
     logger,
 )
 from . import io
@@ -48,20 +47,21 @@ file (without display) (various file formats are supported, indicated
 by file extension).  If the requested extension is 'hdf5' or 'h5' then
 the noise traces and IFO parameters will be saved to an HDF5 file.
 
-If the inspiral_range package is available, various figures of merit
-can be calculated for the resultant spectrum with the --fom option,
-e.g.:
+If the --range option is specified and the inspiral_range package is
+available, various BNS (m1=m2=1.4 M_solar) range figures of merit will
+be calculated for the resultant spectrum.  The default waveform
+parameters can be overriden with the --waveform-parameter/-wp option
+(--range implied if specified) e.g.:
 
-  gwinc --fom horizon ...
-  gwinc --fom range:m1=20,m2=20 ...
+  gwinc -wp m1=20 -wp m2=20 ...
 
 See the inspiral_range package documentation for details.
-NOTE: The range will be calculated with the supplied frequency array,
-and may therefore be inaccurate if a restricted array is specified.
 """
 
 IFO = 'aLIGO'
-FOM = 'range:m1=1.4,m2=1.4'
+FREQ = '5:3000:6000'
+RANGE_PARAMS = ['m1=1.4', 'm2=1.4']
+DATA_SAVE_FORMATS = ['.hdf5', '.h5']
 
 parser = argparse.ArgumentParser(
     prog='gwinc',
@@ -81,8 +81,12 @@ parser.add_argument(
     '--title', '-t',
     help="plot title")
 parser.add_argument(
-    '--fom', metavar='FUNC[:PARAM=VAL,...]', default=FOM,
-    help="use inspiral_range.FUNC to calculate range figure-of-merit on resultant spectrum")
+    '--range', '-r', action='store_true',
+    help="specify inspiral_range parameters, or 'none' to not calculate range")
+parser.add_argument(
+    '--waveform-parameter', '-wp', metavar='PARAM=VAL[,...]', default=RANGE_PARAMS,
+    action='append',
+    help="specify inspiral_range parameters, or 'none' to not calculate range")
 group = parser.add_mutually_exclusive_group()
 group.add_argument(
     '--interactive', '-i', action='store_true',
@@ -122,6 +126,7 @@ def main():
             parser.exit(2, "IFO parameter specification not allowed when loading traces from file.\n")
         from .io import load_hdf5
         budget = None
+        name = args.IFO
         trace = load_hdf5(args.IFO)
         freq = trace.freq
         ifo = trace.ifo
@@ -132,15 +137,22 @@ def main():
             freq = freq_from_spec(args.freq)
         except IndexError:
             parser.exit(2, "Improper frequency specification: {}\n".format(args.freq))
-        budget = load_budget(args.IFO, freq=freq)
+        try:
+            budget = load_budget(args.IFO, freq=freq)
+        except RuntimeError as e:
+            parser.exit(2, str(e)+'\n')
+        name = budget.name
         ifo = budget.ifo
         plot_style = getattr(budget, 'plot_style', {})
         trace = None
 
     if args.ifo:
         for paramval in args.ifo:
-            param, val = paramval.split('=', 1)
-            ifo[param] = float(val)
+            try:
+                param, val = paramval.split('=', 1)
+                ifo[param] = float(val)
+            except ValueError:
+                parser.error("Improper IFO parameter specification.")
 
     if args.yaml:
         if not ifo:
@@ -173,10 +185,11 @@ def main():
     out_plot_files = set()
     if args.save:
         args.plot = False
-        for path in args.save:
+        out_files = set(args.save)
+        for path in out_files:
             if os.path.splitext(path)[1] in io.DATA_SAVE_FORMATS:
                 out_data_files.add(path)
-        out_plot_files = set(args.save) - out_data_files
+        out_plot_files = out_files - out_data_files
 
     if args.plot or out_plot_files:
         if out_plot_files:
@@ -195,30 +208,30 @@ def main():
             logger.warning("no display, plotting disabled.")
             args.plot = False
 
-    try:
-        import inspiral_range
-        logger_ir = logging.getLogger('inspiral_range')
-        logger_ir.setLevel(logger.getEffectiveLevel())
-        handler = logging.StreamHandler()
-        handler.setFormatter(logging.Formatter('%(name)s: %(message)s'))
-        logger_ir.addHandler(handler)
-
-    except ModuleNotFoundError:
-        logger.warning("WARNING: inspiral_range package not available, figure of merit will not be calculated.")
-        args.fom = None
-    if args.fom:
+    if args.waveform_parameter:
+        args.range = True
+    if args.range:
         try:
-            range_func, range_func_args = args.fom.split(':')
-        except ValueError:
-            range_func = args.fom
-            range_func_args = ''
+            import inspiral_range
+            logger_ir = logging.getLogger('inspiral_range')
+            logger_ir.setLevel(logger.getEffectiveLevel())
+            handler = logging.StreamHandler()
+            handler.setFormatter(logging.Formatter('%(name)s: %(message)s'))
+            logger_ir.addHandler(handler)
+        except ModuleNotFoundError:
+            logger.warning("WARNING: inspiral_range package not available, figure of merit will not be calculated.")
+            args.range = False
+    if args.range:
         range_params = {}
-        for param in range_func_args.split(','):
+        for param in args.waveform_parameter:
             if not param:
                 continue
-            p, v = param.split('=')
-            if not v:
-                raise ValueError('missing parameter value "{}"'.format(p))
+            try:
+                p, v = param.split('=')
+                if not v:
+                    raise ValueError
+            except ValueError:
+                parser.error("Improper range parameter specification.")
             try:
                 v = float(v)
             except ValueError:
@@ -235,21 +248,23 @@ def main():
     if args.title:
         plot_style['title'] = args.title
     else:
-        plot_style['title'] = plot_style.get(
-            'title',
-            "GWINC Noise Budget: {}".format(args.IFO),
-        )
-    if args.fom:
-        logger.info("calculating inspiral {}...".format(range_func))
-        H = inspiral_range.CBCWaveform(freq, **range_params)
-        logger.debug("waveform params: {}".format(H.params))
-        fom = eval('inspiral_range.{}'.format(range_func))(freq, trace.psd, H=H)
-        logger.info("{}({}) = {:.2f} Mpc".format(range_func, range_func_args, fom))
-        subtitle = 'inspiral {func} {m1}/{m2} $\mathrm{{M}}_\odot$: {fom:.0f} Mpc'.format(
+        plot_style['title'] = "GWINC Noise Budget: {}".format(name)
+
+    if args.range:
+        logger.info("calculating inspiral ranges...")
+        metrics, H = inspiral_range.all_ranges(freq, trace.psd, **range_params)
+        print(f"{H.params['approximant']} {H.params['m1']}/{H.params['m2']} M_solar:")
+        for metric, (value, unit) in metrics.items():
+            if unit is None:
+                unit = ''
+            print(f" {metric}: {value:0.1f} {unit}")
+        range_func = 'range'
+        subtitle = 'inspiral {func} {m1}/{m2} $\mathrm{{M}}_\odot$: {fom:.0f} {unit}'.format(
             func=range_func,
             m1=H.params['m1'],
             m2=H.params['m2'],
-            fom=fom,
+            fom=metrics[range_func][0],
+            unit=metrics[range_func][1] or '',
             )
     else:
         subtitle = None
@@ -261,14 +276,14 @@ def main():
     if args.interactive:
         banner = """GWINC interactive shell
 
-The 'ifo' Struct and 'budget' trace data objects are available for
+The 'ifo' Struct, 'budget', and 'trace' objects are available for
 inspection.  Use the 'whos' command to view the workspace.
 """
         if not args.plot:
             banner += """
-You may plot the budget using the 'plot_budget()' function:
+You may plot the budget using the 'trace.plot()' method:
 
-In [.]: plot_budget(budget, **plot_style)
+In [.]: trace.plot(**plot_style)
 """
         banner += """
 You may interact with the plot using the 'plt' functions, e.g.:
@@ -277,19 +292,20 @@ In [.]: plt.title("foo")
 In [.]: plt.savefig("foo.pdf")
 """
         from IPython.terminal.embed import InteractiveShellEmbed
+        if subtitle:
+            plot_style['title'] += '\n' + subtitle
         ipshell = InteractiveShellEmbed(
             banner1=banner,
             user_ns={
-                'budget': trace,
                 'ifo': ifo,
+                'budget': budget,
+                'trace': trace,
                 'plot_style': plot_style,
-                'plot_budget': plot_budget,
             },
         )
-        ipshell.enable_pylab()
+        ipshell.enable_pylab(import_all=False)
         if args.plot:
-            ipshell.ex("fig = plot_budget(budget, **plot_style)")
-            ipshell.ex("plt.title(plot_style['title'])")
+            ipshell.ex("fig = trace.plot(**plot_style)")
         ipshell()
 
     ##########
@@ -313,8 +329,7 @@ In [.]: plt.savefig("foo.pdf")
         ax = fig.add_subplot(1, 1, 1)
         if subtitle:
             plot_style['title'] += '\n' + subtitle
-        plot_budget(
-            trace,
+        trace.plot(
             ax=ax,
             **plot_style
         )
@@ -322,7 +337,10 @@ In [.]: plt.savefig("foo.pdf")
         if out_plot_files:
             for path in out_plot_files:
                 logger.info("saving budget plot: {}".format(path))
-                fig.savefig(path)
+                try:
+                    fig.savefig(path)
+                except Exception as e:
+                    parser.exit(2, f"Error saving plot: {e}.\n")
         else:
             plt.show()
 
