@@ -14,7 +14,6 @@ from .. import suspension
 # helper functions
 ############################################################
 
-
 def mirror_struct(ifo, tm):
     """Create a "mirror" Struct for a LIGO core optic
 
@@ -124,34 +123,8 @@ def ifo_power(ifo, PRfixed=True):
     power.Tpr = Tpr
     return power
 
-
-def dhdl(f, armlen):
-    """Strain to length conversion for noise power spetra
-
-    This takes into account the GW wavelength and is only important
-    when this is comparable to the detector arm length.
-
-    From R. Schilling, CQG 14 (1997) 1513-1519, equation 5,
-    with n = 1, nu = 0.05, ignoring overall phase and cos(nu)^2.
-    A small value of nu is used instead of zero to avoid infinities.
-
-    Returns the square of the dh/dL function, and the same divided by
-    the arm length squared.
-
-    """
-    c = const.c
-    nu_small = 15*pi/180
-    omega_arm = pi * f * armlen / c
-    omega_arm_f = (1 - sin(nu_small)) * pi * f * armlen / c
-    omega_arm_b = (1 + sin(nu_small)) * pi * f * armlen / c
-    sinc_sqr = 4 / abs(sin(omega_arm_f) * exp(-1j * omega_arm) / omega_arm_f
-                       + sin(omega_arm_b) * exp(1j * omega_arm) / omega_arm_b)**2
-    dhdl_sqr = sinc_sqr / armlen**2
-    return dhdl_sqr, sinc_sqr
-
 ##################################################
 
-
 def precomp_suspension(f, ifo):
     pc = Struct()
     pc.VHCoupling = Struct()
@@ -159,20 +132,21 @@ def precomp_suspension(f, ifo):
         pc.VHCoupling.theta = ifo.Suspension.VHCoupling.theta
     else:
         pc.VHCoupling.theta = ifo.Infrastructure.Length / const.R_earth
-    hForce, vForce, hTable, vTable = suspension.suspQuad(f, ifo.Suspension)
+    hForce, vForce, hTable, vTable, tst_suscept = suspension.suspQuad(
+        f, ifo.Suspension)
     pc.hForce = hForce
     pc.vForce = vForce
     pc.hTable = hTable
     pc.vTable = vTable
+    pc.tst_suscept = tst_suscept
     return pc
 
 
-
-def precomp_quantum(f, ifo):
+@nb.precomp(sustf=precomp_suspension)
+def precomp_quantum(f, ifo, sustf):
     pc = Struct()
-    mirror_mass = mirror_struct(ifo, 'ETM').MirrorMass
     power = ifo_power(ifo)
-    noise_dict = noise.quantum.shotrad(f, ifo, mirror_mass, power)
+    noise_dict = noise.quantum.shotrad(f, ifo, sustf, power)
     pc.ASvac = noise_dict['ASvac']
     pc.SEC = noise_dict['SEC']
     pc.Arm = noise_dict['arm']
@@ -229,11 +203,21 @@ def dhdl(f, armlen):
 
 
 class Strain(nb.Calibration):
+    """Calibrate displacement to strain
+    """
     def calc(self):
         dhdl_sqr, sinc_sqr = dhdl(self.freq, self.ifo.Infrastructure.Length)
         return dhdl_sqr
 
 
+class Force(nb.Calibration):
+    """Calibrate displacement to force
+    """
+    def calc(self):
+        mass = mirror_struct(self.ifo, 'ETM').MirrorMass
+        return (mass * (2*pi*self.freq)**2)**2
+
+
 ############################################################
 # noise sources
 ############################################################
@@ -370,11 +354,44 @@ class StandardQuantumLimit(nb.Noise):
         ETM = mirror_struct(self.ifo, 'ETM')
         return 8 * const.hbar / (ETM.MirrorMass * (2 * np.pi * self.freq) ** 2)
 
+
 #########################
 # seismic
 #########################
 
-class Seismic(nb.Noise):
+class SeismicHorizontal(nb.Noise):
+    """Horizontal seismic noise
+
+    """
+    style = dict(
+        label='Horizontal',
+        color='xkcd:muted blue',
+    )
+
+    @nb.precomp(sustf=precomp_suspension)
+    def calc(self, sustf):
+        nt, nr = noise.seismic.platform_motion(self.freq, self.ifo)
+        n = noise.seismic.seismic_suspension_filtered(sustf, nt, 'horiz')
+        return n * 4
+
+
+class SeismicVertical(nb.Noise):
+    """Vertical seismic noise
+
+    """
+    style = dict(
+        label='Vertical',
+        color='xkcd:brick red',
+    )
+
+    @nb.precomp(sustf=precomp_suspension)
+    def calc(self, sustf):
+        nt, nr = noise.seismic.platform_motion(self.freq, self.ifo)
+        n = noise.seismic.seismic_suspension_filtered(sustf, nt, 'vert')
+        return n * 4
+
+
+class Seismic(nb.Budget):
     """Seismic
 
     """
@@ -383,20 +400,10 @@ class Seismic(nb.Noise):
         color='#855700',
     )
 
-    @nb.precomp(sustf=precomp_suspension)
-    def calc(self, sustf):
-        if 'PlatformMotion' in self.ifo.Seismic:
-            if self.ifo.Seismic.PlatformMotion == 'BSC':
-                nt, nr = noise.seismic.seismic_BSC_ISI(self.freq)
-            elif self.ifo.Seismic.PlatformMotion == '6D':
-                nt, nr = noise.seismic.seismic_BSC_ISI_6D(self.freq)
-            else:
-                nt, nr = noise.seismic.seismic_BSC_ISI(self.freq)
-        else:
-            nt, nr = noise.seismic.seismic_BSC_ISI(self.freq)
-        n, nh, nv = noise.seismic.seismic_suspension_fitered(
-            self.ifo.Suspension, sustf, nt)
-        return n * 4
+    noises = [
+        SeismicHorizontal,
+        SeismicVertical,
+    ]
 
 
 #########################
@@ -464,20 +471,168 @@ class NewtonianInfrasound(nb.Noise):
 # suspension thermal
 #########################
 
-class SuspensionThermal(nb.Noise):
+class SuspensionThermalHorizTop(nb.Noise):
+    """Horizontal suspension thermal around the top mass
+
+    """
+    style = dict(
+        label='Horiz. Top',
+        color='xkcd:orangeish',
+        alpha=0.7,
+    )
+
+    @nb.precomp(sustf=precomp_suspension)
+    def calc(self, sustf):
+        n = noise.suspensionthermal.susptherm_stage(
+            self.freq, self.ifo.Suspension, sustf, 0, 'horiz')
+        return abs(n) * 4
+
+
+class SuspensionThermalHorizAPM(nb.Noise):
+    """Horizontal suspension thermal around the upper intermediate mass
+
+    """
+    style = dict(
+        label='Horiz. APM',
+        color='xkcd:mustard',
+        alpha=0.7,
+    )
+
+    @nb.precomp(sustf=precomp_suspension)
+    def calc(self, sustf):
+        n = noise.suspensionthermal.susptherm_stage(
+            self.freq, self.ifo.Suspension, sustf, 1, 'horiz')
+        return abs(n) * 4
+
+
+class SuspensionThermalHorizPUM(nb.Noise):
+    """Horizontal suspension thermal around the penultimate mass
+
+    """
+    style = dict(
+        label='Horiz. PUM',
+        color='xkcd:turquoise',
+        alpha=0.7,
+    )
+
+    @nb.precomp(sustf=precomp_suspension)
+    def calc(self, sustf):
+        n = noise.suspensionthermal.susptherm_stage(
+            self.freq, self.ifo.Suspension, sustf, 2, 'horiz')
+        return abs(n) * 4
+
+
+class SuspensionThermalHorizTM(nb.Noise):
+    """Horizontal suspension thermal around the test
+
+    """
+    style = dict(
+        label='Horiz. Test mass',
+        color='xkcd:bright purple',
+        alpha=0.7,
+    )
+
+    @nb.precomp(sustf=precomp_suspension)
+    def calc(self, sustf):
+        precomp_suspension(self.freq, self.ifo)
+        n = noise.suspensionthermal.susptherm_stage(
+            self.freq, self.ifo.Suspension, sustf, 3, 'horiz')
+        return abs(n) * 4
+
+
+class SuspensionThermalVertTop(nb.Noise):
+    """Vertical suspension thermal around the top mass
+
+    """
+    style = dict(
+        label='Vert. Top',
+        color='xkcd:orangeish',
+        linestyle='--',
+        alpha=0.7,
+    )
+
+    @nb.precomp(sustf=precomp_suspension)
+    def calc(self, sustf):
+        n = noise.suspensionthermal.susptherm_stage(
+            self.freq, self.ifo.Suspension, sustf, 0, 'vert')
+        return abs(n) * 4
+
+
+class SuspensionThermalVertAPM(nb.Noise):
+    """Vertical suspension thermal around the upper intermediate mass
+
+    """
+    style = dict(
+        label='Vert. APM',
+        color='xkcd:mustard',
+        linestyle='--',
+        alpha=0.7,
+    )
+
+    @nb.precomp(sustf=precomp_suspension)
+    def calc(self, sustf):
+        n = noise.suspensionthermal.susptherm_stage(
+            self.freq, self.ifo.Suspension, sustf, 1, 'vert')
+        return abs(n) * 4
+
+
+class SuspensionThermalVertPUM(nb.Noise):
+    """Vertical suspension thermal around the penultimate mass
+
+    """
+    style = dict(
+        label='Vert. PUM',
+        color='xkcd:turquoise',
+        linestyle='--',
+        alpha=0.7,
+    )
+
+    @nb.precomp(sustf=precomp_suspension)
+    def calc(self, sustf):
+        n = noise.suspensionthermal.susptherm_stage(
+            self.freq, self.ifo.Suspension, sustf, 2, 'vert')
+        return abs(n) * 4
+
+
+class SuspensionThermalVertTM(nb.Noise):
+    """Vertical suspension thermal around the test
+
+    """
+    style = dict(
+        label='Vert. Test mass',
+        color='xkcd:bright purple',
+        linestyle='--',
+        alpha=0.7,
+    )
+
+    @nb.precomp(sustf=precomp_suspension)
+    def calc(self, sustf):
+        n = noise.suspensionthermal.susptherm_stage(
+            self.freq, self.ifo.Suspension, sustf, 3, 'vert')
+        return abs(n) * 4
+
+
+class SuspensionThermal(nb.Budget):
     """Suspension Thermal
 
     """
+
+    name = 'SuspensionThermal'
+
     style = dict(
         label='Suspension Thermal',
         color='#0d75f8',
     )
 
-    @nb.precomp(sustf=precomp_suspension)
-    def calc(self, sustf):
-        n = noise.suspensionthermal.suspension_thermal(
-            self.freq, self.ifo.Suspension, sustf)
-        return n * 4
+    noises = [
+        SuspensionThermalHorizTop,
+        SuspensionThermalHorizAPM,
+        SuspensionThermalHorizPUM,
+        SuspensionThermalHorizTM,
+        SuspensionThermalVertTop,
+        SuspensionThermalVertAPM,
+        SuspensionThermalVertPUM,
+    ]
 
 
 #########################
@@ -597,7 +752,6 @@ class SubstrateThermoElastic(nb.Noise):
 # residual gas
 #########################
 
-
 class ExcessGas(nb.Noise):
     """Excess Gas
 
